# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------
"""Customize generated code here.

Follow our quickstart for examples: https://aka.ms/azsdk/python/dpcodegen/python/customize
"""
from typing import Any

from azure.core import PipelineClient
from azure.core.pipeline import PipelineRequest
from azure.core.pipeline.policies import BearerTokenCredentialPolicy
from msrest import Deserializer, Serializer

from . import models
from ._affinda_api import AffindaAPI as AffindaAPIGenerated
from ._configuration import AffindaAPIConfiguration
from .token_credential import TokenCredential


class BearerTokenWithoutTLSEnforcementPolicy(BearerTokenCredentialPolicy):
    """
    Patch the credential policy to no longer enforce https, allows the client lib
    to be used with http://localhost etc
    """

    def on_request(self, request: PipelineRequest):
        request.context.options["enforce_https"] = False
        return super().on_request(request)


class AffindaAPI(AffindaAPIGenerated):
    def __init__(
        self,
        credential,  # type: "TokenCredential"
        **kwargs,  # type: Any
    ):
        if "base_url" not in kwargs:
            _base_url = "https://{region}.affinda.com"
        else:
            _base_url = kwargs.pop("base_url")

        if "authentication_policy" not in kwargs:
            kwargs["authentication_policy"] = BearerTokenWithoutTLSEnforcementPolicy(credential)

        self._config = AffindaAPIConfiguration(credential=credential, **kwargs)
        self._client = PipelineClient(base_url=_base_url, config=self._config, **kwargs)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)
        self._serialize.client_side_validation = False


__all__ = ["AffindaAPI"]


def patch_sdk():
    """Do not remove from this file.

    `patch_sdk` is a last resort escape hatch that allows you to do customizations
    you can't accomplish using the techniques described in
    https://aka.ms/azsdk/python/dpcodegen/python/customize
    """



from typing import TYPE_CHECKING

from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.pipeline.transport import AsyncHttpResponse
from azure.core.rest import HttpRequest

from ... import models as _models
from ..._vendor import _convert_request

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from typing import Any, Callable, Dict, Optional, TypeVar, Union  # noqa: F401

    T = TypeVar("T")
    ClsType = Optional[
        Callable[[PipelineResponse[HttpRequest, AsyncHttpResponse], T, Dict[str, Any]], Any]
    ]

from ._affinda_api_operations import (
    AffindaAPIOperationsMixin as AffindaAPIOperationsMixinGenerated,
)
from ._affinda_api_operations import build_get_document_request


# We want to patch the generated AffindaAPIOperationsMixin class, and override its get_document method.
class AffindaAPIOperationsMixin(AffindaAPIOperationsMixinGenerated):
    # Modify this method as the autogenerate one creates duplicate methods, see
    # https://github.com/Azure/autorest.python/issues/1555
    async def get_document(
        self,
        identifier,  # type: str
        format=None,  # type: Optional[Union[str, "_models.DocumentFormat"]]
        **kwargs,  # type: Any
    ):
        # type: (...) -> Union[_models.Document, _models.Resume, _models.Invoice, _models.JobDescription]
        """Get specific document.

        Return a specific document.

        :param identifier: Document's identifier.
        :type identifier: str
        :param format: Specify which format you want the response to be. Default is "json".
        :type format: str or ~affinda.models.DocumentFormat
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: Document, or the result of cls(response)
        :rtype: ~affinda.models.Document
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        error_map = {
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            400: lambda response: HttpResponseError(
                response=response, model=self._deserialize(_models.RequestError, response)
            ),
            401: lambda response: ClientAuthenticationError(
                response=response, model=self._deserialize(_models.RequestError, response)
            ),
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = kwargs.pop("params", {}) or {}

        cls = kwargs.pop("cls", None)  # type: ClsType[_models.Document]

        request = build_get_document_request(
            identifier=identifier,
            format=format,
            template_url=self.get_document.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        path_format_arguments = {
            "region": self._serialize.url("self._config.region", self._config.region, "str"),
        }
        request.url = self._client.format_url(request.url, **path_format_arguments)  # type: ignore

        pipeline_response = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )
        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("Document", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_document.metadata = {"url": "/v3/documents/{identifier}"}  # type: ignore


__all__ = [
    "AffindaAPIOperationsMixin",
]


def patch_sdk():
    """Do not remove from this file.

    `patch_sdk` is a last resort escape hatch that allows you to do customizations
    you can't accomplish using the techniques described in
    https://aka.ms/azsdk/python/dpcodegen/python/customize
    """



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.9.6, generator: @autorest/python@5.16.0)
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AnnotationContentType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The different data types of annotations"""

    TEXT = "text"
    INTEGER = "integer"
    FLOAT = "float"
    DECIMAL = "decimal"
    DATE = "date"
    DATETIME = "datetime"
    BOOLEAN = "boolean"
    ENUM = "enum"
    LOCATION = "location"
    JSON = "json"
    TABLE = "table"
    CELL = "cell"
    EXPECTEDREMUNERATION = "expectedremuneration"
    JOBTITLE = "jobtitle"
    LANGUAGE = "language"
    SKILL = "skill"
    YEARSEXPERIENCE = "yearsexperience"
    GROUP = "group"
    TABLE_DEPRECATED = "table_deprecated"


class CollectionDateFormatPreference(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    DMY = "DMY"
    MDY = "MDY"
    YMD = "YMD"


class DateFormatPreference(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    DMY = "DMY"
    MDY = "MDY"
    YMD = "YMD"


class DateRange(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    TODAY = "today"
    YESTERDAY = "yesterday"
    WEEK = "week"
    MONTH = "month"
    YEAR = "year"


class DocumentFormat(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    JSON = "json"
    XML = "xml"
    HR_XML = "hr-xml"


class DocumentState(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    UPLOADED = "uploaded"
    REVIEW = "review"
    VALIDATED = "validated"
    ARCHIVED = "archived"
    REJECTED = "rejected"


class EducationLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    SCHOOL = "school"
    CERTIFICATE = "certificate"
    BACHELORS = "bachelors"
    MASTERS = "masters"
    DOCTORAL = "doctoral"


class Enum20(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    RESUMES = "resumes"
    JOB_DESCRIPTIONS = "job_descriptions"


class Enum23(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    RESUMES = "resumes"
    JOB_DESCRIPTIONS = "job_descriptions"


class Get8ItemsItem(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    FILE_NAME = "file_name"
    EXTRACTOR = "extractor"
    CREATED_DT = "created_dt"


class GetResponses200ContentApplicationJsonSchemaResultsItemDocumentType(
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):

    RESUMES = "resumes"
    JOB_DESCRIPTIONS = "job_descriptions"


class InvitationResponseStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    ACCEPTED = "accepted"
    DECLINED = "declined"


class InvitationStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    PENDING = "pending"
    ACCEPTED = "accepted"
    DECLINED = "declined"


class ManagementLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    NONE = "None"
    LOW = "Low"
    MID = "Mid"
    UPPER = "Upper"


class OrganizationRole(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    ADMIN = "admin"
    MEMBER = "member"


class OrganizationUserRole(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The role of the logged in user within the organization."""

    ADMIN = "admin"
    MEMBER = "member"


class PostContentSchemaDocumentType(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    RESUMES = "resumes"
    JOB_DESCRIPTIONS = "job_descriptions"


class Region(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """region - server parameter"""

    API = "api"
    API_EU1 = "api.eu1"


class ResthookEvent(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The event name to subscribe to."""

    RESUME_PARSE_SUCCEEDED = "resume.parse.succeeded"
    RESUME_PARSE_FAILED = "resume.parse.failed"
    RESUME_PARSE_COMPLETED = "resume.parse.completed"
    INVOICE_PARSE_SUCCEEDED = "invoice.parse.succeeded"
    INVOICE_PARSE_FAILED = "invoice.parse.failed"
    INVOICE_PARSE_COMPLETED = "invoice.parse.completed"
    INVOICE_VALIDATE_COMPLETED = "invoice.validate.completed"
    DOCUMENT_PARSE_SUCCEEDED = "document.parse.succeeded"
    DOCUMENT_PARSE_FAILED = "document.parse.failed"
    DOCUMENT_PARSE_COMPLETED = "document.parse.completed"
    DOCUMENT_VALIDATE_COMPLETED = "document.validate.completed"
    DOCUMENT_CLASSIFY_SUCCEEDED = "document.classify.succeeded"
    DOCUMENT_CLASSIFY_FAILED = "document.classify.failed"
    DOCUMENT_CLASSIFY_COMPLETED = "document.classify.completed"
    DOCUMENT_REJECTED = "document.rejected"


class ResthookSubscriptionVersion(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Version of the resthook subscription. Determines the resthook body being fired."""

    V1 = "v1"
    V2 = "v2"
    V3 = "v3"


class ResumeDataLanguagesItem(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    AINU = "Ainu"
    AKAN = "Akan"
    AKKADIAN = "Akkadian"
    AMHARIC = "Amharic"
    ANAM = "Anam"
    ARABIC = "Arabic"
    ARAMAIC = "Aramaic"
    AREM = "Arem"
    ARMENIAN = "Armenian"
    AWADHI = "Awadhi"
    AYMARA = "Aymara"
    AZARI = "Azari"
    BAGHELI = "Bagheli"
    BAGRI = "Bagri"
    BAHASA = "Bahasa"
    BAMBARA = "Bambara"
    BANGALA = "Bangala"
    BARDI = "Bardi"
    BASSA = "Bassa"
    BATAK = "Batak"
    BELARUSIAN = "Belarusian"
    BEMBA = "Bemba"
    BENGA = "Benga"
    BENGALI = "Bengali"
    BERBER = "Berber"
    BHOJPURI = "Bhojpuri"
    BISLAMA = "Bislama"
    BRAHUI = "Brahui"
    BULGARIAN = "Bulgarian"
    BUNU = "Bunu"
    CAMBODIAN = "Cambodian"
    CAREW = "Carew"
    CARIB = "Carib"
    CATALAN = "Catalan"
    CEBUANO = "Cebuano"
    CHAKMA = "Chakma"
    CHAMORRO = "Chamorro"
    CHANGO = "Chango"
    CHEWA = "Chewa"
    CROATIAN = "Croatian"
    CZECH = "Czech"
    DAGBANI = "Dagbani"
    DANISH = "Danish"
    DARI = "Dari"
    DAYI = "Dayi"
    DHATKI = "Dhatki"
    DHIVEHI = "Dhivehi"
    DINKA = "Dinka"
    DOGRI = "Dogri"
    DUALA = "Duala"
    DUTCH = "Dutch"
    ENGLISH = "English"
    ESPERANTO = "Esperanto"
    ESTONIAN = "Estonian"
    EWONDO = "Ewondo"
    FAROESE = "Faroese"
    FILIPINO = "Filipino"
    FINNISH = "Finnish"
    FORMULA = "Formula"
    FRENCH = "French"
    FRISIAN = "Frisian"
    FRIULIAN = "Friulian"
    FULA = "Fula"
    GAELIC = "Gaelic"
    GALO = "Galo"
    GARHWALI = "Garhwali"
    GARIFUNA = "Garifuna"
    GERMAN = "German"
    GIKUYU = "Gikuyu"
    GUJARATI = "Gujarati"
    GUJERATI = "Gujerati"
    GWERE = "Gwere"
    HAWAIIAN = "Hawaiian"
    HAYA = "Haya"
    HEBREW = "Hebrew"
    HINDI = "Hindi"
    HMU = "Hmu"
    HOKKIEN = "Hokkien"
    HOPI = "Hopi"
    HUNGARIAN = "Hungarian"
    HUP = "Hup"
    IBANAG = "Ibanag"
    IGBO = "Igbo"
    ILOKANO = "Ilokano"
    INDONESIAN = "Indonesian"
    INTERMEDIATE = "Intermediate"
    IRISH = "Irish"
    ITALIAN = "Italian"
    JAPANESE = "Japanese"
    JIBA = "Jiba"
    KACHIN = "Kachin"
    KALENJIN = "Kalenjin"
    KAMAYO = "Kamayo"
    KANNADA = "Kannada"
    KAONDE = "Kaonde"
    KAYAN = "Kayan"
    KHANDESHI = "Khandeshi"
    KHMER = "Khmer"
    KIKUYU = "Kikuyu"
    KODAVA = "Kodava"
    KOMA = "Koma"
    KONGO = "Kongo"
    KONKANI = "Konkani"
    KOREAN = "Korean"
    KORWA = "Korwa"
    KREYOL = "Kreyol"
    KRIO = "Krio"
    KUMAONI = "Kumaoni"
    KURDISH = "Kurdish"
    KURUKH = "Kurukh"
    KWA = "Kwa"
    LADINO = "Ladino"
    LANGO = "Lango"
    LATVIAN = "Latvian"
    LAWA = "Lawa"
    LINGALA = "Lingala"
    LITHUANIAN = "Lithuanian"
    LULE = "Lule"
    LUXEMBOURGISH = "Luxembourgish"
    MAGAHI = "Magahi"
    MAITHILI = "Maithili"
    MALAY = "Malay"
    MALAYALAM = "Malayalam"
    MALAYSIAN = "Malaysian"
    MALVI = "Malvi"
    MANINKA = "Maninka"
    MANIPURI = "Manipuri"
    MANX = "Manx"
    MARATHI = "Marathi"
    MAYAN = "Mayan"
    MEDUMBA = "Medumba"
    MEMONI = "Memoni"
    MEWARI = "Mewari"
    MIZO = "Mizo"
    MONTENEGRIN = "Montenegrin"
    MWAN = "Mwan"
    MWANGA = "Mwanga"
    NDEBELE = "Ndebele"
    NEPALI = "Nepali"
    NIMADI = "Nimadi"
    ORIYA = "Oriya"
    OROMO = "Oromo"
    OVAMBO = "Ovambo"
    PAMONA = "Pamona"
    PANGASINAN = "Pangasinan"
    PASHTO = "Pashto"
    PHOENICIAN = "Phoenician"
    POLISH = "Polish"
    PORTUGUESE = "Portuguese"
    PULAAR = "Pulaar"
    PULAR = "Pular"
    PUNJABI = "Punjabi"
    QUECHA = "Quecha"
    RAJASTHANI = "Rajasthani"
    ROMANIAN = "Romanian"
    RUSSIAN = "Russian"
    SAKHA = "Sakha"
    SANGO = "Sango"
    SANTHALI = "Santhali"
    SARAIKI = "Saraiki"
    SEIM = "Seim"
    SHADING = "Shading"
    SHAMA = "Shama"
    SHAN = "Shan"
    SHONA = "Shona"
    SILESIAN = "Silesian"
    SINDHI = "Sindhi"
    SLOVAK = "Slovak"
    SLOVENE = "Slovene"
    SOGA = "Soga"
    SOGDIAN = "Sogdian"
    SOTHO = "Sotho"
    SPANISH = "Spanish"
    SUDANESE = "Sudanese"
    SUMERIAN = "Sumerian"
    SURAJPURI = "Surajpuri"
    SURIGAONON = "Surigaonon"
    SWATI = "Swati"
    SWAZI = "Swazi"
    SWEDISH = "Swedish"
    TAGALOG = "Tagalog"
    TAMIL = "Tamil"
    TAUSUG = "Tausug"
    TELUGU = "Telugu"
    TETUM = "Tetum"
    THARU = "Tharu"
    TIBETAN = "Tibetan"
    TIGRINYA = "Tigrinya"
    TRIPURI = "Tripuri"
    TSWANA = "Tswana"
    TULU = "Tulu"
    TURKISH = "Turkish"
    TUWALI = "Tuwali"
    UBI = "Ubi"
    UKRAINIAN = "Ukrainian"
    URDU = "Urdu"
    VEPS = "Veps"
    VIETNAMESE = "Vietnamese"
    WAGDI = "Wagdi"
    WAZIRI = "Waziri"
    XHOSA = "Xhosa"
    YIDDISH = "Yiddish"
    YORUBA = "Yoruba"


class ResumeSkillSourcesItemSection(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    ACHIEVEMENTS = "Achievements"
    ADDITIONAL_INFORMATION = "AdditionalInformation"
    EDUCATION = "Education"
    EXTRACURRICULARS = "Extracurriculars"
    ORGANISATIONS = "Organisations"
    OTHER = "Other"
    PERSONAL_DETAILS = "PersonalDetails"
    PROJECTS = "Projects"
    PUBLICATIONS = "Publications"
    REFEREES = "Referees"
    SKILLS = "Skills"
    SUMMARY = "Summary"
    TRAINING = "Training"
    WORK_EXPERIENCE = "WorkExperience"
    NOT_POPULATED = "NotPopulated"
    HEADER = "Header"
    FOOTER = "Footer"
    SKILLS_INTERESTS_LANGUAGES = "Skills/Interests/Languages"
    TRAINING_CERTIFICATIONS = "Training/Certifications"
    EXTRACURRICULARS_LEADERSHIP = "Extracurriculars/Leadership"


class SearchLocationUnit(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    KM = "km"
    MI = "mi"


class SearchParametersCustomDataFilterType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Data points of "text" type support only "equals" filterType, others support both "equals" and
    "range"
    """

    EQUALS = "equals"
    RANGE = "range"


class ThemeConfigPaletteMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):

    LIGHT = "light"
    DARK = "dark"


class Version(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Version of the resthook subscription. Determines the resthook body being fired."""

    V1 = "v1"
    V2 = "v2"
    V3 = "v3"


class WorkspaceSplitDocumentsOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Option "leave" means no document splitting at all. Option "conservative" means we don't
    actually split documents the documents, but will add a warning to documents that may require a
    split. Option "recommended" means we split documents that are highly likely to require a split,
    and add warnings to documents that might require one. Option "aggressive" means we split all
    documents that are likely to require a split.
    """

    LEAVE = "leave"
    CONSERVATIVE = "conservative"
    RECOMMENDED = "recommended"
    AGGRESSIVE = "aggressive"


class WorkspaceVisibility(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Visibility "organization" means everyone in the organization can access the workspace.
    Visibility "private" means only people explicitly added can access the workspace.
    """

    ORGANIZATION = "organization"
    PRIVATE = "private"
